==> openshift-model-operator-5.10.1-sources.jar: io/fabric8/openshift/api/model/operator/v1/AddPageFluentImpl.java <==
package io.fabric8.openshift.api.model.operator.v1;

import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class AddPageFluentImpl<A extends io.fabric8.openshift.api.model.operator.v1.AddPageFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.operator.v1.AddPageFluent<A>{
  public AddPageFluentImpl() {
  }
  public AddPageFluentImpl(io.fabric8.openshift.api.model.operator.v1.AddPage instance) {
    this.withDisabledActions(instance.getDisabledActions()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.util.List<java.lang.String> disabledActions = new java.util.ArrayList<java.lang.String>();
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public A addToDisabledActions(java.lang.Integer index,java.lang.String item) {
    if (this.disabledActions == null) {this.disabledActions = new java.util.ArrayList<java.lang.String>();}
    this.disabledActions.add(index, item);
    return (A)this;
  }
  public A setToDisabledActions(java.lang.Integer index,java.lang.String item) {
    if (this.disabledActions == null) {this.disabledActions = new java.util.ArrayList<java.lang.String>();}
    this.disabledActions.set(index, item); return (A)this;
  }
  public A addToDisabledActions(java.lang.String... items) {
    if (this.disabledActions == null) {this.disabledActions = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.disabledActions.add(item);} return (A)this;
  }
  public A addAllToDisabledActions(java.util.Collection<java.lang.String> items) {
    if (this.disabledActions == null) {this.disabledActions = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.disabledActions.add(item);} return (A)this;
  }
  public A removeFromDisabledActions(java.lang.String... items) {
    for (java.lang.String item : items) {if (this.disabledActions!= null){ this.disabledActions.remove(item);}} return (A)this;
  }
  public A removeAllFromDisabledActions(java.util.Collection<java.lang.String> items) {
    for (java.lang.String item : items) {if (this.disabledActions!= null){ this.disabledActions.remove(item);}} return (A)this;
  }
  public java.util.List<java.lang.String> getDisabledActions() {
    return this.disabledActions;
  }
  public java.lang.String getDisabledAction(java.lang.Integer index) {
    return this.disabledActions.get(index);
  }
  public java.lang.String getFirstDisabledAction() {
    return this.disabledActions.get(0);
  }
  public java.lang.String getLastDisabledAction() {
    return this.disabledActions.get(disabledActions.size() - 1);
  }
  public java.lang.String getMatchingDisabledAction(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: disabledActions) { if(predicate.test(item)){ return item;} } return null;
  }
  public java.lang.Boolean hasMatchingDisabledAction(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: disabledActions) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withDisabledActions(java.util.List<java.lang.String> disabledActions) {
    if (disabledActions != null) {this.disabledActions = new java.util.ArrayList<java.lang.String>(); for (java.lang.String item : disabledActions){this.addToDisabledActions(item);}} else { this.disabledActions = null;} return (A) this;
  }
  public A withDisabledActions(java.lang.String... disabledActions) {
    if (this.disabledActions != null) {this.disabledActions.clear();}
    if (disabledActions != null) {for (java.lang.String item :disabledActions){ this.addToDisabledActions(item);}} return (A) this;
  }
  public java.lang.Boolean hasDisabledActions() {
    return disabledActions != null && !disabledActions.isEmpty();
  }
  public A addNewDisabledAction(java.lang.String arg0) {
    return (A)addToDisabledActions(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    AddPageFluentImpl that = (AddPageFluentImpl) o;
    if (disabledActions != null ? !disabledActions.equals(that.disabledActions) :that.disabledActions != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(disabledActions,  additionalProperties,  super.hashCode());
  }
  
}

==> openshift-model-operator-5.12.4-sources.jar: io/fabric8/openshift/api/model/operator/v1/AddPageFluentImpl.java <==
package io.fabric8.openshift.api.model.operator.v1;

import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class AddPageFluentImpl<A extends io.fabric8.openshift.api.model.operator.v1.AddPageFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.operator.v1.AddPageFluent<A>{
  public AddPageFluentImpl() {
  }
  public AddPageFluentImpl(io.fabric8.openshift.api.model.operator.v1.AddPage instance) {
    this.withDisabledActions(instance.getDisabledActions()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.util.List<java.lang.String> disabledActions = new java.util.ArrayList<java.lang.String>();
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public A addToDisabledActions(java.lang.Integer index,java.lang.String item) {
    if (this.disabledActions == null) {this.disabledActions = new java.util.ArrayList<java.lang.String>();}
    this.disabledActions.add(index, item);
    return (A)this;
  }
  public A setToDisabledActions(java.lang.Integer index,java.lang.String item) {
    if (this.disabledActions == null) {this.disabledActions = new java.util.ArrayList<java.lang.String>();}
    this.disabledActions.set(index, item); return (A)this;
  }
  public A addToDisabledActions(java.lang.String... items) {
    if (this.disabledActions == null) {this.disabledActions = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.disabledActions.add(item);} return (A)this;
  }
  public A addAllToDisabledActions(java.util.Collection<java.lang.String> items) {
    if (this.disabledActions == null) {this.disabledActions = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.disabledActions.add(item);} return (A)this;
  }
  public A removeFromDisabledActions(java.lang.String... items) {
    for (java.lang.String item : items) {if (this.disabledActions!= null){ this.disabledActions.remove(item);}} return (A)this;
  }
  public A removeAllFromDisabledActions(java.util.Collection<java.lang.String> items) {
    for (java.lang.String item : items) {if (this.disabledActions!= null){ this.disabledActions.remove(item);}} return (A)this;
  }
  public java.util.List<java.lang.String> getDisabledActions() {
    return this.disabledActions;
  }
  public java.lang.String getDisabledAction(java.lang.Integer index) {
    return this.disabledActions.get(index);
  }
  public java.lang.String getFirstDisabledAction() {
    return this.disabledActions.get(0);
  }
  public java.lang.String getLastDisabledAction() {
    return this.disabledActions.get(disabledActions.size() - 1);
  }
  public java.lang.String getMatchingDisabledAction(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: disabledActions) { if(predicate.test(item)){ return item;} } return null;
  }
  public java.lang.Boolean hasMatchingDisabledAction(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: disabledActions) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withDisabledActions(java.util.List<java.lang.String> disabledActions) {
    if (disabledActions != null) {this.disabledActions = new java.util.ArrayList(); for (java.lang.String item : disabledActions){this.addToDisabledActions(item);}} else { this.disabledActions = null;} return (A) this;
  }
  public A withDisabledActions(java.lang.String... disabledActions) {
    if (this.disabledActions != null) {this.disabledActions.clear();}
    if (disabledActions != null) {for (java.lang.String item :disabledActions){ this.addToDisabledActions(item);}} return (A) this;
  }
  public java.lang.Boolean hasDisabledActions() {
    return disabledActions != null && !disabledActions.isEmpty();
  }
  public A addNewDisabledAction(java.lang.String arg0) {
    return (A)addToDisabledActions(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    AddPageFluentImpl that = (AddPageFluentImpl) o;
    if (disabledActions != null ? !disabledActions.equals(that.disabledActions) :that.disabledActions != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(disabledActions,  additionalProperties,  super.hashCode());
  }
  
}
